use crate::{
    app::authentication::{AuthToken, AuthSecret},
    util::pack::{pack_u8, pack_u16},
};

use super::Packet;

#[derive(Clone)]
pub struct PacketAuthResume {
    pub token:AuthToken,
    pub secret:AuthSecret,
}
impl PacketAuthResume {
    pub fn new() -> Self
    {
        Self {
            token:AuthToken::default(),
            secret:AuthSecret::default(),
        }
    }
}
impl Packet for PacketAuthResume {
    type Data = Self;

    fn decode(data:&Vec<u8>, index:&mut usize) -> Result<Self::Data, ()>
    {
        let mut result = Self::new();

        if data.len() - *index == 24 {
            for i in 0..8 { result.token[i] = data[*index]; *index += 1; }
            for i in 0..16 { result.secret[i] = data[*index]; *index += 1; }
            Ok(result)
        } else {
            Err(())
        }
    }
}


#[derive(Clone)]
pub struct PacketAuthResumeResponse {
    pub status:u16,
    pub handle:String,
}
impl PacketAuthResumeResponse {
    pub fn new() -> Self
    {
        Self {
            status:0,
            handle:String::new(),
        }
    }
}
impl Packet for PacketAuthResumeResponse {
    type Data = Self;

    fn encode(&self) -> Vec<u8>
    {
        let handle_bytes = self.handle.as_bytes().to_vec();
        [
            pack_u16(self.status),
            pack_u8(handle_bytes.len() as u8),
            handle_bytes,
        ].concat()
    }
}
